==> ZenTaoPMS.16.5.php7.2_7.4.zip: zentaopms/extension/biz/my/ext/model/class/effort.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPsfu1uY9m/kluC+IgqMPhmUaCTxPm1HKMka0SOSopaH2as3l0fXlMsTeyjTo/ZJahqvBuRPG
FvSgNnSafDQ3K5U5N/2H850VdeFMEEB5BcxL8lsntqzEeXVqHOz8N55LAN90mXx1H5fd5XOGmhIG
cBpyCcWm/K0s4gi9MtVh31VUVwqx1XX7liE/4z9Uow7Gyu7vPgv2Y1H5oys/puwI8T7jGj6V+Uiz
+jYyD1+S4fkc58nKuhrjItyaKErJJKAOs8upL9uLtd9lKQw2Ci2sVLxSvIPGDSODrMYOFNw948Ex
Q+Qv29S5UW3iHHTyqcKBpxcs3WuvUUIoi6bDVxf/J/0EvQiZmLNV6x6KiyETi2Ev6RbdH6CEXrwT
3py8gn/dr//Bd5/7WOuKbm21ahOhH/PaeZOBOW3zpTHHTt4U/6fZbrBCLRuwq2QVfeUMHsf4rPat
XipBegnjg4RbWeysskIVlMjACseReJQA3bP9/a29nub2MEwT/Ib+IFd/BMFZDaWm/yA/BFIBXJUA
sIlAESoh5vQlj/72IYGRbqxXN310o8LGaqSMMkfgWnCoofSuSOtHMMql79FwqHFeHTXqQDpZ6F6W
mpVMynNbHdsnfRJk0hLBmz+cXLw3mnvTCQOvw1Lm7n8tB/pQUmZKASuV5YA+dOGi2CVr+gDf7Hea
TbqYAq70wJe0ROJVVndimddjLTug+UhxvYbmO74HHVA+tExw+4+L2SHUQ9ovxy6oc4t1BAc/xBIZ
j8tUCMtBeBqEUGTRtAZGKPw07qmgFawF4sf7ASgBqFAMzWmlBw1gkFtGU+zVHs3Clvk4wi5HtoSx
KcmcbNSpeec2gQ7DBZkMMnwTRj9HatiB4Nm55XZmg4EeG/5FmDME6eNNiA5nom6mYqqJolC97yBw
JXzM7dQwJk4SwMU7Bylmyr2E+suNnSIhiCiHhy+gzABS8zYH3SP5i48gj5UEzbqJCZ8veO3zox0m
8qNld416M3iC9ftw85bHPBr10ZiWR31hxYqi+3yDWRNtJCpqYrGqNpS5cinIrGNXJWLNTCPHZAMo
P89cVr5Znvv7lZ3ii3OqNyg2/5GcEZJ3NWr9KyQQn5nbddF/vHCKGiNmkUVPnd8BuDT2hdWOD4V9
owgIr79a3vrjtfns3QbBUkSsvtt8eGxNmWNZiNj+ouH1KPTwcE5Hy9/xpsxgKaXu41eTm63qNM1V
Fco0uMSFkmbrcxFDrCi/+Oeq+Cg1ntuP5ybUAAfnbpYUX+zkStpTmmp7WasC/T7+X9Bg0exLRBTy
+Jel3XpEh1shcZft+o1xHHf+M15x6DoZuDdXLgawwurJbXQi0mYwdfwO+Vt2ntJnyKmP00zZRgtC
T33BVlsd2rDOqEtg2b0nZUq3mMz9IS0QQxF1Sy6IRmkrc8t3tbUy3cxMjZOzbJMQpMD4rDQmt3kn
mzaOZMdwLLr2uAE/jNR7BRG4289qpVlTDbZSav03c+kMfp7hMa5LnQqG2fPP/6aqDqy+RMtYtlbL
Sq9AsWmkmHI5aaWKVkGmPfy2Y1E/ugBxFnBBq9RacxJqjlISIWtcKr+YWdPGDYTFr5Znjdc9gqPQ
hyo+K88=

==> ZenTaoPMS.17.1.php5.4_5.6.zip: zentaopms/extension/biz/my/ext/model/class/effort.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPowIXcrhU7j2oYSJJeVGgB7ek7A5dwj2HLtmb+5ftU4qBra5Xbpb6BBRfY2IWUC/l0KaUkGb
aviiDUzQefLkVtPJkKfpQL0pEqx6KP+nacmACcdJY59j+EU1TiidQaDNA5mC5VVkvLwGZxjKXPTw
N/BuAzZwMx02+kZkemNkFl2v4eVaiF0p9RINGZMOmDruFs05PtI8Yv5qb3Q8pmbrynuvd9WtkAWS
+9pUNEAAnjTZZTRdZhNCcTFiQkRDbY3jsDJapCwE00qopt4lj+MdtpVVHhPKMZVV6lVReoKS1v93
eloLMGbw+vmx4PZP/qrZG4ItSGDbyAZFv3FWW5kr7QodZ/LpH54ZD2IT5+P+8m8jCb8RfrD42Set
QfWvCf0Y24iFAAdzwlcB/0yWF0F/d1JTehzKm8dCDhHm75WqihggOa0NK7m9PwoLZlQfNTB+rKz2
6CeTwO1p0bvu8gsefW+I7ZGch3qDmRkGdhs/YmsKpjqxZYBVDYa67Ni8ktNzQU6GkhRCSUDeM6UG
V4pfwyxH1is+37T9aML1hLuAupOq2z/bRPd72VAJ5wYvIaILnsNb0eRouSWrrxMXA0X9R5yN6gPw
DKl9GLzeIa0EpRlf9X1zdURQI+cwQXp7edabwTXeWkuNzqaLHtviBktf3KHffY1PpkFiH3GqUw+a
iLip7/WSu2e5SY3fDOjmrqI0ssbzxHY83banb08dZglWUlP+3NJB+1Wg4PjF+NkV5s2291M7Fr1s
w38Pslwj38GNrh03CPosTSGKj6poRMibYIpQ04w6JXPMCzL35NxyllJhbA6GmUsjWb/ilg5m1ZCj
R5fg5Tt8r65STQaGvYhsefq2TvGOHSfBkM66LMPrxZgzDQi3im==
